import click
import os
import platform
import pkg_resources

from meerkat import email as send_email
from meerkat.api import get_user_token

@click.group()
def meerkat():
    pass

@meerkat.command()
def ping():
    resource_path = "ping_sounds/default_ping.mp3"
    full_path = pkg_resources.resource_filename(__name__, resource_path)
    print(full_path)
    play_sound(full_path)

@meerkat.command()
@click.argument('message', type=str)
def email(message):
    result = send_email(message=message)
    click.echo(f'{result}')

@meerkat.command()
def login():
    email = click.prompt("Enter Email")
    password = click.prompt("Enter Password", hide_input=True)
    token = get_user_token(email, password)

    if not token:
        click.echo("Invalid email or password.")
        return

    #save token to user HOME and set OS env
    with open(os.path.expanduser("~") + "/.meerkat", "w") as file:
        file.write(token)
    os.environ["MEERKAT_TOKEN"] = token

    click.echo(f"\nMeerkat initialized successfully.")

def play_sound(file_name: str):
    system = platform.system()
    if system == 'Darwin':  # macOS
        os.system(f'afplay {file_name}')
    elif system == 'Linux':
        os.system(f'aplay {file_name}')
    elif system == 'Windows':
        os.system(f'powershell -c "(New-Object Media.SoundPlayer \'{file_name}\').PlaySync();"')
    else:
        click.echo('Unsupported operating system.')

if __name__ == "__main__":
    meerkat()


import os
import time
from playsound import playsound

from meerkat.api import send_meerkat_notification, get_user_token

module_runtime = int(time.time()*1000)

if not os.environ.get("MEERKAT_TOKEN"):
    try:
        with open(os.path.expanduser("~") + "/.meerkat") as file:
            os.environ["MEERKAT_TOKEN"] = file.read()
    except Exception as e:
        print(e)
        pass

#
# User Management Functions
#
def login(email: str, password: str) -> bool:
    token = get_user_token(email, password)

    if not token:
        print("Invalid Meerkat Token!")
        return False

    os.environ["MEERKAT_TOKEN"] = token
    return True

#
# Notification Functions
#
def email(token=None, message=""):
    if token == None:
        token = os.environ.get("MEERKAT_TOKEN")

    if not token:
        return
    
    return send_meerkat_notification("email", token, message)


import IPython.core.ultratb
from IPython import get_ipython
import requests
import json
import time
import sys
from pathlib import Path


def slack_message(message):
    config_file = str(Path.home() / ".slack_magic")

    try:
        with open(config_file) as f:
            webhook_url = f.read()
    except FileNotFoundError:
        webhook_url = input("Enter your slack app webhook: ")
        with open(config_file, "w") as f:
            f.write(webhook_url)

    slack_data = {"text": message}

    response = requests.post(
        url=webhook_url,
        data=json.dumps(slack_data),
        headers={"Content-Type": "application/json"},
    )
    if response.status_code != 200:
        raise ValueError(
            f"Request to slack returned an error {response.status_code}, the response is:\n{response.text}"
        )


def slack_code(code):
    message = f"```\n{code}\n```"
    return message


def slack_error(traceback):
    message = f":x::x::x:\nYour code failed at {time.strftime('at %H:%M:%S on %a %b %Y')[:-2]} :sob::sob:\n{slack_code(traceback)}"
    slack_message(message)


def slack_success():
    message = f":white_check_mark::white_check_mark::white_check_mark:\nYour code completed at {time.strftime('at %H:%M:%S on %a %b %Y')[:-2]} :relaxed::relaxed:"
    slack_message(message)


def notify(line, cell=None):
    try:
        get_ipython().ex(cell if cell else line)
        slack_success()
    except Exception as exc:
        tb = IPython.core.ultratb.VerboseTB(color_scheme="NoColor", include_vars=False)
        error = tb.text(*sys.exc_info())
        slack_error(error)
        raise

def load_ipython_extension(ipython):
    ipython.register_magic_function(notify, "line_cell")


from setuptools import setup, find_packages

setup(
    name='meerkatio',
    version='1.4',
    packages=find_packages(),
    package_data={'soundfiles': ['ping_sounds/*.mp3']},
    include_package_data=True,
    install_requires=[
        "requests",
        "click"
    ],
    entry_points='''
        [console_scripts]
        meerkat=meerkat.cli:meerkat
    ''',
    author="meerkat.io",
    description="Simple notification tool for multi-tasking developers"
    # Add other metadata such as author, author_email, description, etc.
)
